function Res = PipeResistance(length, diameter, viscosity)
%PipeResistance calculates the laminar flow resistance of a pipe
%  Res = PipeResistance(length, diameter, viscosity)
%  Res is in units of Pa*s/m^3 (kg s^-1 m^-4)
%  length is the pipe length, in meters
%  diameter is the pipe diameter, in meters
%  viscosity is the fluid viscosity, in kg m^-1 s^-1, for mineral oil, it is .1
%  note .1 kg m^-1 s^-1 = 1 poise (g cm^-1 s^-1)

% BTL Jan 17 2002

rad = diameter/2;
Res = (8*viscosity*length)/(pi*rad^4);

